@@ -3,7 +3,7 @@ import sys
 import click
 from suds.cache import NoCache
 from suds.client import Client
-from suds.transport.http import HttpAuthenticated
+from suds.transport.https import HttpAuthenticated
 
 from gestionatr.input.messages import message
 from gestionatr.input.messages import message_gas
@@ -58,7 +58,17 @@ def test(filename, sector):
 
 def request_p0(url, user, password, xml_file):
     t = HttpAuthenticated(username=user, password=password)
-    client = Client(url, transport=t, cache=NoCache())
+    import urllib2
+    try:
+        import base64
+        base64string = base64.encodestring('%s:%s' % (user, password)).replace('\n', '')
+        authenticationHeader = {"Authorization": "Basic %s" % base64string, "SOAPAction": "syncRequest"}  # {"Authorization": "Basic %s" % 'MDcwNjpFTkUxOTAjMDY='}
+        client = Client(url, transport=t, soapheaders=authenticationHeader)
+        client.set_options(headers=authenticationHeader)
+    except urllib2.URLError as e:
+        import ssl
+        ssl._create_default_https_context = ssl._create_unverified_context
+        client = Client(url, transport=t)
 
     if isinstance(xml_file, str):
         xml_str = xml_file
